kbus-mock Library
Mock implementation of the kbus crate for testing.
Structs
- KBus
- The primary type representing a mock connection to a K-Bus device.
Enums
- Error
- Error types returned by the kbus-mock library.
Functions
- get_
output_ bit - Get the current state of an output bit, useful for tests.
- reset_
state - Reset all simulated I/O data to default values, useful between tests.
- set_
input_ bit - Set a simulated input bit value, useful for tests.